elixr.sax
=========
SqlAlchemy eXtension: a toolkit of reusable SQLAlchemy types, data models and 
utility functions encapsulating best practices or exposing convenient facades
for data access and handling.
